@@ -76,6 +76,7 @@ NONSTANDARD = {
     'HSE': set(['cyclic', 'basic', 'surface', 'large', 'polar']),
     'HSP': set(['cyclic', 'acidic', 'surface', 'large', 'polar']),
     'MSE': set(['acyclic', 'neutral', 'buried', 'large']),
+    'CME': set(['acyclic', 'neutral', 'buried', 'large']),
     'SEC': set(['acyclic', 'neutral', 'buried', 'polar', 'medium']),
     'SEP': set(['acyclic', 'surface', 'acidic', 'large', 'polar']),
     'TPO': set(['acyclic', 'surface', 'acidic', 'large', 'polar']),
@@ -83,6 +84,8 @@ NONSTANDARD = {
     'PHD': set(['acyclic', 'acidic', 'surface', 'polar', 'large']),
     'XLE': set(['aliphatic', 'acyclic', 'buried', 'hydrophobic', 'large']),
     'XAA': set(),
+    'MEN': set(),
+    'CSB': set()
 }
 
 DEFAULTS = {
